@@ -10,6 +10,8 @@ from .freecad_impl import importers
 from .selectors import *
 from .cq import *
 
+import warnings
+
 
 __all__ = [
     'CQ','Workplane','plugins','selectors','Plane','BoundBox','Matrix','Vector','sortWiresByBuildOrder',
@@ -18,4 +20,6 @@ __all__ = [
     'TypeSelector','DirectionMinMaxSelector','StringSyntaxSelector','Selector','plugins',
 ]
 
-__version__ = "1.2.0"
+__version__ = "1.2.2"
+
+warnings.warn("CadQuery 1.x is no longer supported. Please upgrade to CadQuery 2.x https://github.com/CadQuery/cadquery", DeprecationWarning)
